==> 0.0.5.tar.gz: lib/theme/app_style.dart <==
import 'package:flutter/material.dart';
import 'package:basic_utils_flutter/app_export.dart';

class AppStyle {
  static TextStyle txtSFProTextBold10 = TextStyle(
    color: ColorConstant.teal500,
    fontSize: getFontSize(
      10,
    ),
    fontFamily: 'SF Pro Text',
    fontWeight: FontWeight.w700,
  );

  static TextStyle txtSFProDisplayRegular17 = TextStyle(
    color: ColorConstant.blueGray900,
    fontSize: getFontSize(
      17,
    ),
    fontFamily: 'SF Pro Display',
    fontWeight: FontWeight.w400,
  );


  static TextStyle txtSFProDisplayRegular13LightBlue = TextStyle(
    color: ColorConstant.lightBlue,
    fontSize: getFontSize(
      13,
    ),
    fontFamily: 'SF Pro Display',
    fontWeight: FontWeight.w400,
  );

  static TextStyle txtSFProTextRegular16 = TextStyle(
    color: ColorConstant.blueGray40001,
    fontSize: getFontSize(
      16,
    ),
    fontFamily: 'SF Pro Text',
    fontWeight: FontWeight.w400,
  );

  static TextStyle txtSFProTextSemibold17 = TextStyle(
    color: ColorConstant.whiteA700,
    fontSize: getFontSize(
      17,
    ),
    fontFamily: 'SF Pro Text',
    fontWeight: FontWeight.w600,
  );

  static TextStyle txtSFProTextRegular17 = TextStyle(
    color: ColorConstant.teal500,
    fontSize: getFontSize(
      17,
    ),
    fontFamily: 'SF Pro Text',
    fontWeight: FontWeight.w400,
  );

  static TextStyle txtFootnote = TextStyle(
    color: ColorConstant.blueGray900,
    fontSize: getFontSize(
      13,
    ),
    fontFamily: 'SF Pro Display',
    fontWeight: FontWeight.w400,
  );

  static TextStyle txtSFProTextRegular15 = TextStyle(
    color: ColorConstant.gray80099,
    fontSize: getFontSize(
      15,
    ),
    fontFamily: 'SF Pro Text',
    fontWeight: FontWeight.w400,
  );

  static TextStyle txtSFProDisplayRegular13 = TextStyle(
    color: ColorConstant.teal500,
    fontSize: getFontSize(
      13,
    ),
    fontFamily: 'SF Pro Display',
    fontWeight: FontWeight.w400,
  );

  static TextStyle txtSFProTextRegular12 = TextStyle(
    color: ColorConstant.gray80099,
    fontSize: getFontSize(
      12,
    ),
    fontFamily: 'SF Pro Text',
    fontWeight: FontWeight.w400,
  );

  static TextStyle txtSFProTextRegular13 = TextStyle(
    color: ColorConstant.gray900A3,
    fontSize: getFontSize(
      13,
    ),
    fontFamily: 'SF Pro Text',
    fontWeight: FontWeight.w400,
  );
  static TextStyle txtSFProTextRegular13Black900 = TextStyle(
    color: ColorConstant.black90066,
    fontSize: getFontSize(
      13,
    ),
    fontFamily: 'SF Pro Text',
    fontWeight: FontWeight.w400,
  );

  static TextStyle txtSFProTextRegular13Black = TextStyle(
    color: ColorConstant.black900,
    fontSize: getFontSize(
      13,
    ),
    fontFamily: 'SF Pro Text',
    fontWeight: FontWeight.w400,
  );


  static TextStyle txtSFProDisplayRegular11 = TextStyle(
    color: ColorConstant.blueGray900,
    fontSize: getFontSize(
      11,
    ),
    fontFamily: 'SF Pro Display',
    fontWeight: FontWeight.w400,
  );

  static TextStyle txtSFProDisplayRegular12 = TextStyle(
    color: ColorConstant.black900,
    fontSize: getFontSize(
      12,
    ),
    fontFamily: 'SF Pro Display',
    fontWeight: FontWeight.w400,
  );


  static TextStyle txtSFProDisplayBold14 = TextStyle(
    color: ColorConstant.blueGray900,
    fontSize: getFontSize(
      14,
    ),
    fontFamily: 'SF Pro Display',
    fontWeight: FontWeight.w700,
  );

  static TextStyle txtSFProDisplayBold14Gray = TextStyle(
    color: ColorConstant.gray80099,
    fontSize: getFontSize(
      17,
    ),
    fontFamily: 'SF Pro Display',
    fontWeight: FontWeight.w700,
  );

  static TextStyle txtSFProDisplayBold17 = TextStyle(
    color: ColorConstant.blueGray900,
    fontSize: getFontSize(
      17,
    ),
    fontFamily: 'SF Pro Display',
    fontWeight: FontWeight.w700,
  );

  static TextStyle txtSFProTextRegular17Black900 = TextStyle(
    color: ColorConstant.black900,
    fontSize: getFontSize(
      17,
    ),
    fontFamily: 'SF Pro Text',
    fontWeight: FontWeight.w400,
  );

  static TextStyle txtSFProTextRegular15Gray80099 = TextStyle(
    color: ColorConstant.gray80099,
    fontSize: getFontSize(
      13,
    ),
    fontFamily: 'SF Pro Text',
    fontWeight: FontWeight.w100,
  );

  static TextStyle txtSFProDisplayRegular12Bluegray900 = TextStyle(
    color: ColorConstant.blueGray900,
    fontSize: getFontSize(
      12,
    ),
    fontFamily: 'SF Pro Display',
    fontWeight: FontWeight.w400,
  );

  static TextStyle txtSFProDisplayRegular17Bluegray500 = TextStyle(
    color: ColorConstant.blueGray500,
    fontSize: getFontSize(
      17,
    ),
    fontFamily: 'SF Pro Display',
    fontWeight: FontWeight.w400,
  );

  static TextStyle txtSFProTextSemibold17Black900 = TextStyle(
    color: ColorConstant.black900,
    fontSize: getFontSize(
      17,
    ),
    fontFamily: 'SF Pro Text',
    fontWeight: FontWeight.w600,
  );
  static TextStyle txtSFProTextSemibold13Black900 = TextStyle(
    color: ColorConstant.black900,
    fontSize: getFontSize(
      13,
    ),
    fontFamily: 'SF Pro Text',
    fontWeight: FontWeight.w200,
  );

  static TextStyle txtSFProDisplayBold20 = TextStyle(
    color: ColorConstant.blueGray900,
    fontSize: getFontSize(
      20,
    ),
    fontFamily: 'SF Pro Display',
    fontWeight: FontWeight.w700,
  );

  static TextStyle txtSFProDisplayRegular17Black90060 = TextStyle(
    color: ColorConstant.black90060,
    fontSize: getFontSize(
      17,
    ),
    fontFamily: 'SF Pro Display',
    fontWeight: FontWeight.w400,
  );

  static TextStyle txtSFProTextRegular17Blue600 = TextStyle(
    color: ColorConstant.blue600,
    fontSize: getFontSize(
      17,
    ),
    fontFamily: 'SF Pro Text',
    fontWeight: FontWeight.w400,
  );

  static TextStyle txtSFProTextSemibold13 = TextStyle(
    color: ColorConstant.black900,
    fontSize: getFontSize(
      13,
    ),
    fontFamily: 'SF Pro Text',
    fontWeight: FontWeight.w600,
  );

  static TextStyle txtRobotoRegular20 = TextStyle(
    color: ColorConstant.black900,
    fontSize: getFontSize(
      20,
    ),
    fontFamily: 'Roboto',
    fontWeight: FontWeight.w400,
  );

  static TextStyle txtSFProDisplayRegular17Bluegray90001 = TextStyle(
    color: ColorConstant.blueGray90001,
    fontSize: getFontSize(
      17,
    ),
    fontFamily: 'SF Pro Display',
    fontWeight: FontWeight.w400,
  );

  static TextStyle txtSFProTextMedium13 = TextStyle(
    color: ColorConstant.black900,
    fontSize: getFontSize(
      13,
    ),
    fontFamily: 'SF Pro Text',
    fontWeight: FontWeight.w500,
  );

  static TextStyle txtSFProDisplayRegular17Black90066 = TextStyle(
    color: ColorConstant.black90066,
    fontSize: getFontSize(
      17,
    ),
    fontFamily: 'SF Pro Display',
    fontWeight: FontWeight.w400,
  );

  static TextStyle txtSFProDisplaySemibold4627 = TextStyle(
    color: ColorConstant.whiteA700,
    fontSize: getFontSize(
      46.27,
    ),
    fontFamily: 'SF Pro Display',
    fontWeight: FontWeight.w600,
  );

  static TextStyle txtSFProTextMedium10 = TextStyle(
    color: ColorConstant.gray500,
    fontSize: getFontSize(
      10,
    ),
    fontFamily: 'SF Pro Text',
    fontWeight: FontWeight.w500,
  );

  static TextStyle txtSFProTextRegular17Gray80099 = TextStyle(
    color: ColorConstant.gray80099,
    fontSize: getFontSize(
      17,
    ),
    fontFamily: 'SF Pro Text',
    fontWeight: FontWeight.w400,
  );

  static TextStyle txtSFProDisplayRegular17Black900 = TextStyle(
    color: ColorConstant.black900,
    fontSize: getFontSize(
      17,
    ),
    fontFamily: 'SF Pro Display',
    fontWeight: FontWeight.w400,
  );

  static TextStyle txtSFProDisplayRegular17Gray900 = TextStyle(
    color: ColorConstant.gray900,
    fontSize: getFontSize(
      17,
    ),
    fontFamily: 'SF Pro Display',
    fontWeight: FontWeight.w400,
  );

  static TextStyle txtSFProDisplaySemibold17 = TextStyle(
    color: ColorConstant.blueGray90001,
    fontSize: getFontSize(
      17,
    ),
    fontFamily: 'SF Pro Display',
    fontWeight: FontWeight.w600,
  );

  static TextStyle txtSFProTextRegular17RedA200 = TextStyle(
    color: ColorConstant.redA200,
    fontSize: getFontSize(
      17,
    ),
    fontFamily: 'SF Pro Text',
    fontWeight: FontWeight.w400,
  );

  static TextStyle txtSFProTextRegular17RedA200White = TextStyle(
    color: ColorConstant.whiteA700,
    fontSize: getFontSize(
      17,
    ),
    fontFamily: 'SF Pro Text',
    fontWeight: FontWeight.w400,
  );

  static TextStyle txtSFProDisplaySemibold548 = TextStyle(
    color: ColorConstant.black900,
    fontSize: getFontSize(
      5.48,
    ),
    fontFamily: 'SF Pro Display',
    fontWeight: FontWeight.w600,
  );

  static TextStyle txtSFProDisplayBold12Gray900a3 = TextStyle(
    color: ColorConstant.gray900A3,
    fontSize: getFontSize(
      12,
    ),
    fontFamily: 'SF Pro Display',
    fontWeight: FontWeight.w700,
  );

  static TextStyle txtSFProDisplayLight10 = TextStyle(
    color: ColorConstant.blueGray900,
    fontSize: getFontSize(
      10,
    ),
    fontFamily: 'SF Pro Display',
    fontWeight: FontWeight.w300,
  );

  static TextStyle txtSFProDisplayBold10 = TextStyle(
    color: ColorConstant.blueGray900,
    fontSize: getFontSize(
      10,
    ),
    fontFamily: 'SF Pro Display',
    fontWeight: FontWeight.w700,
  );

  static TextStyle txtSFProDisplayBold13 = TextStyle(
    color: ColorConstant.teal500,
    fontSize: getFontSize(
      13,
    ),
    fontFamily: 'SF Pro Display',
    fontWeight: FontWeight.w700,
  );

  static TextStyle txtSFProDisplayBold34 = TextStyle(
    color: ColorConstant.blueGray900,
    fontSize: getFontSize(
      34,
    ),
    fontFamily: 'SF Pro Display',
    fontWeight: FontWeight.w700,
  );

  static TextStyle txtSFProDisplayBold12 = TextStyle(
    color: ColorConstant.blueGray400,
    fontSize: getFontSize(
      12,
    ),
    fontFamily: 'SF Pro Display',
    fontWeight: FontWeight.w700,
  );

  static TextStyle txtRobotoRegular16 = TextStyle(
    color: ColorConstant.blueGray40002,
    fontSize: getFontSize(
      16,
    ),
    fontFamily: 'Roboto',
    fontWeight: FontWeight.w400,
  );

  static TextStyle txtSFProDisplaySemibold14 = TextStyle(
    color: ColorConstant.gray90001,
    fontSize: getFontSize(
      14,
    ),
    fontFamily: 'SF Pro Display',
    fontWeight: FontWeight.w600,
  );
  static TextStyle txtSFProDisplaySemibold14QR = TextStyle(
    color: ColorConstant.gray90001,
    fontSize: getFontSize(
      14,
    ),
    fontWeight: FontWeight.w600,
  );


  static TextStyle txtSFProDisplaySemibold13 = TextStyle(
    color: ColorConstant.teal500,
    fontSize: getFontSize(
      13,
    ),
    fontFamily: 'SF Pro Display',
    fontWeight: FontWeight.w600,
  );

  static TextStyle txtSFProDisplayBold34Black900 = TextStyle(
    color: ColorConstant.black900,
    fontSize: getFontSize(
      34,
    ),
    fontFamily: 'SF Pro Display',
    fontWeight: FontWeight.w700,
  );

  static TextStyle txtSFProTextRegular17LightblueA700 = TextStyle(
    color: ColorConstant.lightBlueA700,
    fontSize: getFontSize(
      17,
    ),
    fontFamily: 'SF Pro Text',
    fontWeight: FontWeight.w400,
  );

  static TextStyle txtSFProDisplaySemibold17Bluegray900 = TextStyle(
    color: ColorConstant.blueGray900,
    fontSize: getFontSize(
      17,
    ),
    fontFamily: 'SF Pro Display',
    fontWeight: FontWeight.w600,
  );

  static TextStyle txtSFProTextSemibold17Bluegray900 = TextStyle(
    color: ColorConstant.blueGray900,
    fontSize: getFontSize(
      17,
    ),
    fontFamily: 'SF Pro Text',
    fontWeight: FontWeight.w600,
  );

  static TextStyle txtSFProTextSemibold21Bluegray900 = TextStyle(
    color: ColorConstant.blueGray900,
    fontSize: getFontSize(
      24,
    ),
    fontFamily: 'SF Pro Text',
    fontWeight: FontWeight.w900,
  );

  static TextStyle txtSFProDisplayMedium22 = TextStyle(
    color: ColorConstant.black900,
    fontSize: getFontSize(
      22,
    ),
    fontFamily: 'SF Pro Display',
    fontWeight: FontWeight.w500,
  );
}

==> 0.0.8.tar.gz: lib/theme/app_style.dart <==
import 'package:flutter/material.dart';
import 'package:basic_utils_flutter/app_export.dart';

class AppStyle {
  static TextStyle txtSFProTextBold10 = TextStyle(
    color: BadColorConstant.teal500,
    fontSize: getFontSize(
      10,
    ),
    fontFamily: 'SF Pro Text',
    fontWeight: FontWeight.w700,
  );

  static TextStyle txtSFProDisplayRegular17 = TextStyle(
    color: BadColorConstant.blueGray900,
    fontSize: getFontSize(
      17,
    ),
    fontFamily: 'SF Pro Display',
    fontWeight: FontWeight.w400,
  );

  static TextStyle txtSFProDisplayRegular13LightBlue = TextStyle(
    color: BadColorConstant.lightBlue,
    fontSize: getFontSize(
      13,
    ),
    fontFamily: 'SF Pro Display',
    fontWeight: FontWeight.w400,
  );

  static TextStyle txtSFProTextRegular16 = TextStyle(
    color: BadColorConstant.blueGray40001,
    fontSize: getFontSize(
      16,
    ),
    fontFamily: 'SF Pro Text',
    fontWeight: FontWeight.w400,
  );

  static TextStyle txtSFProTextSemibold17 = TextStyle(
    color: BadColorConstant.whiteA700,
    fontSize: getFontSize(
      17,
    ),
    fontFamily: 'SF Pro Text',
    fontWeight: FontWeight.w600,
  );

  static TextStyle txtSFProTextRegular17 = TextStyle(
    color: BadColorConstant.teal500,
    fontSize: getFontSize(
      17,
    ),
    fontFamily: 'SF Pro Text',
    fontWeight: FontWeight.w400,
  );

  static TextStyle txtFootnote = TextStyle(
    color: BadColorConstant.blueGray900,
    fontSize: getFontSize(
      13,
    ),
    fontFamily: 'SF Pro Display',
    fontWeight: FontWeight.w400,
  );

  static TextStyle txtSFProTextRegular15 = TextStyle(
    color: BadColorConstant.gray80099,
    fontSize: getFontSize(
      15,
    ),
    fontFamily: 'SF Pro Text',
    fontWeight: FontWeight.w400,
  );

  static TextStyle txtSFProDisplayRegular13 = TextStyle(
    color: BadColorConstant.teal500,
    fontSize: getFontSize(
      13,
    ),
    fontFamily: 'SF Pro Display',
    fontWeight: FontWeight.w400,
  );

  static TextStyle txtSFProTextRegular12 = TextStyle(
    color: BadColorConstant.gray80099,
    fontSize: getFontSize(
      12,
    ),
    fontFamily: 'SF Pro Text',
    fontWeight: FontWeight.w400,
  );

  static TextStyle txtSFProTextRegular13 = TextStyle(
    color: BadColorConstant.gray900A3,
    fontSize: getFontSize(
      13,
    ),
    fontFamily: 'SF Pro Text',
    fontWeight: FontWeight.w400,
  );
  static TextStyle txtSFProTextRegular13Black900 = TextStyle(
    color: BadColorConstant.black90066,
    fontSize: getFontSize(
      13,
    ),
    fontFamily: 'SF Pro Text',
    fontWeight: FontWeight.w400,
  );

  static TextStyle txtSFProTextRegular13Black = TextStyle(
    color: BadColorConstant.black900,
    fontSize: getFontSize(
      13,
    ),
    fontFamily: 'SF Pro Text',
    fontWeight: FontWeight.w400,
  );

  static TextStyle txtSFProDisplayRegular11 = TextStyle(
    color: BadColorConstant.blueGray900,
    fontSize: getFontSize(
      11,
    ),
    fontFamily: 'SF Pro Display',
    fontWeight: FontWeight.w400,
  );

  static TextStyle txtSFProDisplayRegular12 = TextStyle(
    color: BadColorConstant.black900,
    fontSize: getFontSize(
      12,
    ),
    fontFamily: 'SF Pro Display',
    fontWeight: FontWeight.w400,
  );

  static TextStyle txtSFProDisplayBold14 = TextStyle(
    color: BadColorConstant.blueGray900,
    fontSize: getFontSize(
      14,
    ),
    fontFamily: 'SF Pro Display',
    fontWeight: FontWeight.w700,
  );

  static TextStyle txtSFProDisplayBold14Gray = TextStyle(
    color: BadColorConstant.gray80099,
    fontSize: getFontSize(
      17,
    ),
    fontFamily: 'SF Pro Display',
    fontWeight: FontWeight.w700,
  );

  static TextStyle txtSFProDisplayBold17 = TextStyle(
    color: BadColorConstant.blueGray900,
    fontSize: getFontSize(
      17,
    ),
    fontFamily: 'SF Pro Display',
    fontWeight: FontWeight.w700,
  );

  static TextStyle txtSFProTextRegular17Black900 = TextStyle(
    color: BadColorConstant.black900,
    fontSize: getFontSize(
      17,
    ),
    fontFamily: 'SF Pro Text',
    fontWeight: FontWeight.w400,
  );

  static TextStyle txtSFProTextRegular15Gray80099 = TextStyle(
    color: BadColorConstant.gray80099,
    fontSize: getFontSize(
      13,
    ),
    fontFamily: 'SF Pro Text',
    fontWeight: FontWeight.w100,
  );

  static TextStyle txtSFProDisplayRegular12Bluegray900 = TextStyle(
    color: BadColorConstant.blueGray900,
    fontSize: getFontSize(
      12,
    ),
    fontFamily: 'SF Pro Display',
    fontWeight: FontWeight.w400,
  );

  static TextStyle txtSFProDisplayRegular17Bluegray500 = TextStyle(
    color: BadColorConstant.blueGray500,
    fontSize: getFontSize(
      17,
    ),
    fontFamily: 'SF Pro Display',
    fontWeight: FontWeight.w400,
  );

  static TextStyle txtSFProTextSemibold17Black900 = TextStyle(
    color: BadColorConstant.black900,
    fontSize: getFontSize(
      17,
    ),
    fontFamily: 'SF Pro Text',
    fontWeight: FontWeight.w600,
  );
  static TextStyle txtSFProTextSemibold13Black900 = TextStyle(
    color: BadColorConstant.black900,
    fontSize: getFontSize(
      13,
    ),
    fontFamily: 'SF Pro Text',
    fontWeight: FontWeight.w200,
  );

  static TextStyle txtSFProDisplayBold20 = TextStyle(
    color: BadColorConstant.blueGray900,
    fontSize: getFontSize(
      20,
    ),
    fontFamily: 'SF Pro Display',
    fontWeight: FontWeight.w700,
  );

  static TextStyle txtSFProDisplayRegular17Black90060 = TextStyle(
    color: BadColorConstant.black90060,
    fontSize: getFontSize(
      17,
    ),
    fontFamily: 'SF Pro Display',
    fontWeight: FontWeight.w400,
  );

  static TextStyle txtSFProTextRegular17Blue600 = TextStyle(
    color: BadColorConstant.blue600,
    fontSize: getFontSize(
      17,
    ),
    fontFamily: 'SF Pro Text',
    fontWeight: FontWeight.w400,
  );

  static TextStyle txtSFProTextSemibold13 = TextStyle(
    color: BadColorConstant.black900,
    fontSize: getFontSize(
      13,
    ),
    fontFamily: 'SF Pro Text',
    fontWeight: FontWeight.w600,
  );

  static TextStyle txtRobotoRegular20 = TextStyle(
    color: BadColorConstant.black900,
    fontSize: getFontSize(
      20,
    ),
    fontFamily: 'Roboto',
    fontWeight: FontWeight.w400,
  );

  static TextStyle txtSFProDisplayRegular17Bluegray90001 = TextStyle(
    color: BadColorConstant.blueGray90001,
    fontSize: getFontSize(
      17,
    ),
    fontFamily: 'SF Pro Display',
    fontWeight: FontWeight.w400,
  );

  static TextStyle txtSFProTextMedium13 = TextStyle(
    color: BadColorConstant.black900,
    fontSize: getFontSize(
      13,
    ),
    fontFamily: 'SF Pro Text',
    fontWeight: FontWeight.w500,
  );

  static TextStyle txtSFProDisplayRegular17Black90066 = TextStyle(
    color: BadColorConstant.black90066,
    fontSize: getFontSize(
      17,
    ),
    fontFamily: 'SF Pro Display',
    fontWeight: FontWeight.w400,
  );

  static TextStyle txtSFProDisplaySemibold4627 = TextStyle(
    color: BadColorConstant.whiteA700,
    fontSize: getFontSize(
      46.27,
    ),
    fontFamily: 'SF Pro Display',
    fontWeight: FontWeight.w600,
  );

  static TextStyle txtSFProTextMedium10 = TextStyle(
    color: BadColorConstant.gray500,
    fontSize: getFontSize(
      10,
    ),
    fontFamily: 'SF Pro Text',
    fontWeight: FontWeight.w500,
  );

  static TextStyle txtSFProTextRegular17Gray80099 = TextStyle(
    color: BadColorConstant.gray80099,
    fontSize: getFontSize(
      17,
    ),
    fontFamily: 'SF Pro Text',
    fontWeight: FontWeight.w400,
  );

  static TextStyle txtSFProDisplayRegular17Black900 = TextStyle(
    color: BadColorConstant.black900,
    fontSize: getFontSize(
      17,
    ),
    fontFamily: 'SF Pro Display',
    fontWeight: FontWeight.w400,
  );

  static TextStyle txtSFProDisplayRegular17Gray900 = TextStyle(
    color: BadColorConstant.gray900,
    fontSize: getFontSize(
      17,
    ),
    fontFamily: 'SF Pro Display',
    fontWeight: FontWeight.w400,
  );

  static TextStyle txtSFProDisplaySemibold17 = TextStyle(
    color: BadColorConstant.blueGray90001,
    fontSize: getFontSize(
      17,
    ),
    fontFamily: 'SF Pro Display',
    fontWeight: FontWeight.w600,
  );

  static TextStyle txtSFProTextRegular17RedA200 = TextStyle(
    color: BadColorConstant.redA200,
    fontSize: getFontSize(
      17,
    ),
    fontFamily: 'SF Pro Text',
    fontWeight: FontWeight.w400,
  );

  static TextStyle txtSFProTextRegular17RedA200White = TextStyle(
    color: BadColorConstant.whiteA700,
    fontSize: getFontSize(
      17,
    ),
    fontFamily: 'SF Pro Text',
    fontWeight: FontWeight.w400,
  );

  static TextStyle txtSFProDisplaySemibold548 = TextStyle(
    color: BadColorConstant.black900,
    fontSize: getFontSize(
      5.48,
    ),
    fontFamily: 'SF Pro Display',
    fontWeight: FontWeight.w600,
  );

  static TextStyle txtSFProDisplayBold12Gray900a3 = TextStyle(
    color: BadColorConstant.gray900A3,
    fontSize: getFontSize(
      12,
    ),
    fontFamily: 'SF Pro Display',
    fontWeight: FontWeight.w700,
  );

  static TextStyle txtSFProDisplayLight10 = TextStyle(
    color: BadColorConstant.blueGray900,
    fontSize: getFontSize(
      10,
    ),
    fontFamily: 'SF Pro Display',
    fontWeight: FontWeight.w300,
  );

  static TextStyle txtSFProDisplayBold10 = TextStyle(
    color: BadColorConstant.blueGray900,
    fontSize: getFontSize(
      10,
    ),
    fontFamily: 'SF Pro Display',
    fontWeight: FontWeight.w700,
  );

  static TextStyle txtSFProDisplayBold13 = TextStyle(
    color: BadColorConstant.teal500,
    fontSize: getFontSize(
      13,
    ),
    fontFamily: 'SF Pro Display',
    fontWeight: FontWeight.w700,
  );

  static TextStyle txtSFProDisplayBold34 = TextStyle(
    color: BadColorConstant.blueGray900,
    fontSize: getFontSize(
      34,
    ),
    fontFamily: 'SF Pro Display',
    fontWeight: FontWeight.w700,
  );

  static TextStyle txtSFProDisplayBold12 = TextStyle(
    color: BadColorConstant.blueGray400,
    fontSize: getFontSize(
      12,
    ),
    fontFamily: 'SF Pro Display',
    fontWeight: FontWeight.w700,
  );

  static TextStyle txtRobotoRegular16 = TextStyle(
    color: BadColorConstant.blueGray40002,
    fontSize: getFontSize(
      16,
    ),
    fontFamily: 'Roboto',
    fontWeight: FontWeight.w400,
  );

  static TextStyle txtSFProDisplaySemibold14 = TextStyle(
    color: BadColorConstant.gray90001,
    fontSize: getFontSize(
      14,
    ),
    fontFamily: 'SF Pro Display',
    fontWeight: FontWeight.w600,
  );
  static TextStyle txtSFProDisplaySemibold14QR = TextStyle(
    color: BadColorConstant.gray90001,
    fontSize: getFontSize(
      14,
    ),
    fontWeight: FontWeight.w600,
  );

  static TextStyle txtSFProDisplaySemibold13 = TextStyle(
    color: BadColorConstant.teal500,
    fontSize: getFontSize(
      13,
    ),
    fontFamily: 'SF Pro Display',
    fontWeight: FontWeight.w600,
  );

  static TextStyle txtSFProDisplayBold34Black900 = TextStyle(
    color: BadColorConstant.black900,
    fontSize: getFontSize(
      34,
    ),
    fontFamily: 'SF Pro Display',
    fontWeight: FontWeight.w700,
  );

  static TextStyle txtSFProTextRegular17LightblueA700 = TextStyle(
    color: BadColorConstant.lightBlueA700,
    fontSize: getFontSize(
      17,
    ),
    fontFamily: 'SF Pro Text',
    fontWeight: FontWeight.w400,
  );

  static TextStyle txtSFProDisplaySemibold17Bluegray900 = TextStyle(
    color: BadColorConstant.blueGray900,
    fontSize: getFontSize(
      17,
    ),
    fontFamily: 'SF Pro Display',
    fontWeight: FontWeight.w600,
  );

  static TextStyle txtSFProTextSemibold17Bluegray900 = TextStyle(
    color: BadColorConstant.blueGray900,
    fontSize: getFontSize(
      17,
    ),
    fontFamily: 'SF Pro Text',
    fontWeight: FontWeight.w600,
  );

  static TextStyle txtSFProTextSemibold21Bluegray900 = TextStyle(
    color: BadColorConstant.blueGray900,
    fontSize: getFontSize(
      24,
    ),
    fontFamily: 'SF Pro Text',
    fontWeight: FontWeight.w900,
  );

  static TextStyle txtSFProDisplayMedium22 = TextStyle(
    color: BadColorConstant.black900,
    fontSize: getFontSize(
      22,
    ),
    fontFamily: 'SF Pro Display',
    fontWeight: FontWeight.w500,
  );
}
